summaryrefslogtreecommitdiffstats
path: root/parts/filelist/projectviewpart.h
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2014-05-25 15:37:31 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2014-05-25 15:37:31 +0900
commit6392f5a9dfce2bf83617d49bb7f332181ec6004e (patch)
treeab69e390f7962b7e7dda1a3a64f035c61c751cf4 /parts/filelist/projectviewpart.h
parentaba2788b428dc53243407902e9ccbb20b97a69fd (diff)
downloadtdevelop-6392f5a9dfce2bf83617d49bb7f332181ec6004e.tar.gz
tdevelop-6392f5a9dfce2bf83617d49bb7f332181ec6004e.zip
Revert "Finish renaming tdevelop components"
This reverts commit 722ce1efbac31c61b1d4b13f7e075c9f311e3e73.
Diffstat (limited to 'parts/filelist/projectviewpart.h')
-rw-r--r--parts/filelist/projectviewpart.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/parts/filelist/projectviewpart.h b/parts/filelist/projectviewpart.h
index 72c6efcd..392a9cdf 100644
--- a/parts/filelist/projectviewpart.h
+++ b/parts/filelist/projectviewpart.h
@@ -18,8 +18,8 @@
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
***************************************************************************/
-#ifndef TDEVPROJECTVIEW_H
-#define TDEVPROJECTVIEW_H
+#ifndef KDEVPROJECTVIEW_H
+#define KDEVPROJECTVIEW_H
#include "fileinfo.h"
@@ -27,7 +27,7 @@
#include <tqmap.h>
#include <tqguardedptr.h>
-#include <tdevplugin.h>
+#include <kdevplugin.h>
#include <kurl.h>
@@ -53,7 +53,7 @@ this is a reimplementation of the project views in Quanta
@TODO save html parts too
FIXME at project open I get the default view and the open files at last close
*/
-class ProjectviewPart: public TDevPlugin
+class ProjectviewPart: public KDevPlugin
{
Q_OBJECT
@@ -66,7 +66,7 @@ public:
ProjectviewPart(TQObject *parent, const char *name, const TQStringList &args);
~ProjectviewPart();
// reimplemented from TDevPlugin
void restorePartialProjectSession(const TQDomElement * el);
void savePartialProjectSession(TQDomElement * el);
@@ -66,7 +66,7 @@ public:
ProjectviewPart(TQObject *parent, const char *name, const TQStringList &args);
~ProjectviewPart();
- // reimplemented from TDevPlugin
+ // reimplemented from KDevPlugin
void restorePartialProjectSession(const TQDomElement * el);
void savePartialProjectSession(TQDomElement * el);